.. _tutorials:

Tutorials
=========

In this section you will find step-by-step lessons that guide beginners through the initial setup and basic usage of MetPyRad.

.. toctree::
    :maxdepth: 2
    :caption: Tutorials

    starting
    install
    hidex300/index
